#!/bin/bash

# Submit jobs to cluster for MCMC runs of coag model.
# 
# INPUT:
#	$1 - Total number of function evaluations
#	$2 - Evaluations per job (should evenly divide 1)
#
# OUTPUT:
#	None
#
# By Michael Stobb
# 10/19/17


# Define the number of evaluations per job (default to 2000)
numEvals=${2:-2000}

# Define max evals (default value is 40000)
maxEval=${1:-40000}

# Correct maxEval for loop stepping and for starting at 1
let "maxEval=$maxEval-$numEvals+1"


# Make a new directory and move to it
mkdir general_run1
cd general_run1

# Put in a small README file for documentation
echo "Computed random samples of ODE Coag model with flow.\
  Time span used was 2400s, high shear rate (500/s) with flow velocity = 2.5.\
  Ran on 1/29/17 by Michael Stobb" > README

# Loop over desired function evals, stepping by numEvals
for i in $(seq 1 $numEvals $maxEval)
do
	# make a new run directory, indexed by start of range
	mkdir runStart$i
	cd runStart$i

	# Copy the necessary function files
	cp ../../files/* .

	# Define the end range for this run
	i2=$(echo "$i+$numEvals" | bc)

	# Submit the job and pass the two variables
	qsub -v RSTART=$i -v RSTOP=$i2 run_KFHL.py
	
	# Test to make sure all is working!
	# echo $i $i2  # It was!

	# Change directory back out
	cd ../
done
